# _*_ coding:utf-8 _*_


class ResponseCode:

    InfoGothOK = ["base.InfoGoOK", "信息获取成功"]
    OrganAuthOK = ["auth.OrganAuthOK", "机构验证正确"]
    PhoneAvailableOK = ["base.PhoneAvailableOK", "手机号可用"]
    PhoneChangeOK = ["0", "变更成功"]
    RespOK = ["0", "响应成功"]
    RegisterOK = ["base.RegisterOK", "注册成功"]
    RegisterDuplication = ["base.RegisterDuplication", "重复注册"]
    AccountPasswordAuthOk = ["0", "账号密码正确"]
    UserInfoAuthOk = ["0", "用户信息校验成功"]
    ParamsError = ["base.ParamsError", "参数不正确"]
    RequiredParameterMissingError = ["1", "参数缺失"]
    NonExistent = ["2", "信息不存在或已失效"]
    PhoneAvailableNo = ["base.PhoneAvailableNo", "手机号已占用"]
    IllegalMobile = ["base.IllegalMobile", "手机号不合法"]
    PhoneNonExistent = ["5", "手机号不存在"]
    VerCodeSendSuccess = ["base.VerCodeSendSuccess", "验证码发送成功"]
    VerCodeSendFail = ["base.VerCodeSendFail", "验证码发送失败"]
    PhoneChangeFail = ["6", "变更失败"]
    AccountPasswordAuthFail = ["7", "账号密码验证不通过"]
    RegisterFail = ["7", "注册失败"]
    UserNameError = ["8", "姓名不匹配"]
    PlatformAuthFail = ["8", "平台校验不通过"]
    ServicesError = ["sys.ServicesError.", "服务异常,请稍后重试"]



"""

    存取配置文件中解析出来的字段

"""
# _*_ coding:utf-8 _*_
import collections
from abc import ABCMeta, abstractmethod
from typing import Any, Dict, Tuple


class Collection(metaclass=ABCMeta):

    @abstractmethod
    def set(self, *args, **kwargs):
        pass

    @abstractmethod
    def __getattr__(self, item) -> Any:
        pass


class _Collection(Collection):

    def __init__(self):
        super().__init__()
        self.__pool = dict()

    def set(self, item: Any, key: Any, val: Any):
        old = self.__pool.get(item)
        _temp = None
        if old:
            if isinstance(old, dict):
                pass
            elif isinstance(old, tuple):
                pass
            elif isinstance(old, int) or isinstance(old, float):
                pass
            else:
                """ 先迁移旧item 下的kv， 再更新 """
                fields = getattr(old, '_fields')
                s_fields = set(fields)
                s_fields.add(key)
                _temp = collections.namedtuple(item, list(s_fields))
                for f in fields:
                    setattr(_temp, f, getattr(old, f))
                setattr(_temp, key, val)
        else:
            _temp = collections.namedtuple(item, [key])
            setattr(_temp, key, val)
        self.__pool.update({item: _temp})

    def __getattr__(self, item) -> Any:
        return self.__pool.get(item)

Collector = _Collection()
print("init", id(Collector))



# _*_ coding:utf-8 _*_
import os
import sys


def create_workspace(workspace_name, current_path):
    workspace_path = os.path.join(current_path, workspace_name)
    print('create_workspace:', workspace_path)
    if not os.path.exists(workspace_path):
        os.makedirs(workspace_path)
    return workspace_path


def create_configure(current_path):
    configure_path = os.path.join(current_path, 'configure')
    print('create_configure:', configure_path)
    if not os.path.exists(configure_path):
        os.makedirs(configure_path)
    return configure_path


def create_configure_base___toml(configure_path):
    with open(os.path.join(configure_path, 'base.toml'), 'w') as f:
        f.write(str("""# 环境
[runtime]
env='dev'

[listen]
    [listen.dev]
    ipv4 = '127.0.0.1'
    port = 8088"""))


def create_configure__init___py(configure_path):
    with open(os.path.join(configure_path, '__init__.py'), 'w') as f:
        f.write("")


def create(workspace_name, current_path):
    _workspace_path = create_workspace(workspace_name, current_path)
    create_app(_workspace_path)
    _configure_path = create_configure(current_path)
    create_configure_base___toml(_configure_path)
    create_configure__init___py(_configure_path)


def create_app(workspace_path):
    app_path = os.path.join(workspace_path, 'app')
    print('create_app:', app_path)
    if not os.path.exists(app_path):
        os.makedirs(app_path)
    with open(os.path.join(app_path, 'demo.py'), 'w') as f:
        f.write(str("""# _*_ coding:utf-8 _*_
from Xeu.core.loader.ApplicationCore import *


@app.route(r'', name='Http Method Demo')
class HttpMethodDemoHandler(BaseHandlerCore):

    def initialize(self):
        Logger.info(f'{__class__} Ping pre...')

    @middleware()
    @tornado.gen.coroutine
    def get(self, *args, **kwargs):
        Logger.info(f'{__class__} Ping ...')
        \"\"\"
        :desc 这是文档
        :param args:
        :param kwargs:
        :success return:
        \"\"\"
        try:
            self._res['data'] = "data_data_data"
            self._res['status'] = ResponseCode.InfoGothOK
            self.write(json.dumps(self._res))
            self.finish()
        except Exception as e:
            Logger.info(f'{__class__} Ping [Error] {str(e)}')
            self.write(json.dumps(dict(status=ResponseCode.ServicesError)))
            self.finish()


        """))


class Main(object):

    @staticmethod
    def init(workspace_name, current_path):
        create(workspace_name, current_path)


def run():
    main = Main()
    getattr(main, sys.argv[1])(sys.argv[2], os.getcwd())


if __name__ == '__main__':
    print(sys.argv)
    print(os.getcwd())
    print(sys.path[0])


# _*_ coding:utf-8 _*_
import tornado.web
import copy
from Xeu.configure.init import SETUP_MAIN_ROUTERS
# from Config.LoggingConf import Logger, LFormatRSD, LFormatRS, LFormatR
from Xeu.configure.init import COOKIE_SECRET, TEMPLATES_URL, STATIC_URL, INDEX_FILE

__all__ = ['app', 'router_map_pool', 'api_doc']

from Xeu.logger.conf import Logger

router_map_pool = list()
api_doc = dict()


class __RouterConfig(tornado.web.Application):
    """ 重置Tornado自带的路有对象 """

    def route(self, url, name=None):
        """
        注册模块的路由映射关系
        :param url:
        :param name:
        :return:
        """

        def __register(handler):
            """
            :param handler: URL对应的Handler
            :return: Handler
            """
            #########################
            # 接口下的 http 方法文档 #
            #########################

            __main_url = SETUP_MAIN_ROUTERS.get(str(handler.__module__).split('.')[-1], None)
            api_doc.update({
                str(handler.__module__): dict(
                    get=handler.get.__doc__,
                    post=handler.post.__doc__,
                    patch=handler.patch.__doc__,
                    put=handler.put.__doc__,
                    delete=handler.delete.__doc__,
            )})
            ####################
            # 路由载入 排序 #
            ####################

            __route_url = __main_url is not None and __main_url + url or url
            __route_map = (__route_url, handler)
            router_map_pool.append(__route_map)
            Logger.info(f'[system] routing map preloading {name} <{__route_url}> ')

            # self.add_handlers(".*$", [(main_url is not None and main_url+url or url, handler)])  # URL和Handler对应关系添加到路由表中
            return handler

        return __register


app = __RouterConfig(
    cookie_secret=COOKIE_SECRET,
    template_path=TEMPLATES_URL,
    static_path=STATIC_URL,
    static_handler_args={"default_filename": INDEX_FILE}
)  # 创建Tornado路由对象，默认路由表为空


# _*_ coding:utf-8 _*_

"""
    故障问题的增删改查
"""
import tornado.web
import tornado.gen
import pymysql
import copy
import json

__all__ = ['BaseHandlerCore']


# class BaseHandlerCore(tornado.web.RequestHandler):
#
#     def __init__(self, application, request, **kwargs):
#         self.db_session = None
#         self.db_session_gen = None
#         self.apis = None
#         self._res = {'status': None}
#         super(BaseHandlerCore, self).__init__(application, request, **kwargs)
#
#     def initialize(self):
#
#         """ 初始化信息 """
#
#         Logger.info('[Executor] system [Run] 数据库连接...... ')
#         self.db_session_gen = SessionGen()
#         self.db_session_gen.run_engine()
#         self.db_session = self.db_session_gen.database_connects
#         Logger.info('[Executor] system [Run] 进入处理函数，并且初始化 [Status] 成功 ')
#
#     def on_finish(self):
#         # if self.db_session is not None:
#             try:
#                 self.db_session_gen.close()
#                 Logger.info('[Executor] system [Run]  断开数据库连接 [Status] 成功')
#
#             except Exception as e:
#                 Logger.info('[Executor] system [Run]  断开数据库连接 [Status] 失败 [Detail] %s' % str(e))


class BaseHandlerCore(tornado.web.RequestHandler):

    def __init__(self, application, request, **kwargs):
        self.service = None
        self._res = {'status': None}
        super(BaseHandlerCore, self).__init__(application, request, **kwargs)

    def initialize(self):

        """ 初始化信息 """

        pass

    def on_finish(self):
        pass

    def get_query_argument_json(self, params, default=None):
        __params = self.get_query_argument(params, default)
        if __params in [None, '']:
            return {}
        else:
            __res = json.loads(__params)
            return json.loads(__params)





# _*_ coding:utf-8 _*_
import redis

from Xeu.connector.__base import Connection


class RedisConnection(Connection):

    def __init__(self):
        self.__connector = None

    def connect(self, *args, **kwargs):
        pool = redis.ConnectionPool(
            host=kwargs['host'],
            port=kwargs['port'],
            password=kwargs['password'],
            decode_responses=True
        )
        self.__connector = redis.Redis(connection_pool=pool)
        return self.__connector



# _*_ coding:utf-8 _*_
from Xeu.configure.init import Collector, Setup, BASE_CONFIG_RAW_DATA, LISTEN

from Xeu.task.task_base import TaskClient


class RedisTask(TaskClient):

    def setup_task_env(self):
        """
            初始化任务列表，分为
                待执行任务 ：
                    含任务类型，属性，执行次数
                    * 任务类型：
                    * 属性： instant_times:1 立即执行一次，
                            cron_sec:3 每三秒  cron_time:   每三秒 cron_sec:3 每三秒
                            after_sec:3 三秒后 after_min:1, after_hour:1
                待执行任务批次队列
                正在执行任务列表
                执行失败任务列表
                执行结束任务列表
        :return:
        """
        Setup(base_config=('base.toml',))
        print(Collector, id(Collector))
        print(Collector.LISTEN.port)
        print(Collector.LISTEN.ipv4)
        # a = BASE_CONFIG_RAW_DATA
        # print(BASE_CONFIG_RAW_DATA.current_env_data.redis)

    def create_task(self):
        pass

    def stop_task(self):
        pass

    def query_task(self):
        pass

    def list_tasks(self, *args, **kwargs):
        pass


# _*_ coding:utf-8 _*_
from Xeu.configure.init import Setup, Collector

if __name__ == '__main__':
    Setup(base_config=('base.toml', ))
    print(Collector.runtime)
    print(Collector.listen.port)
    print(Collector.listen.ipv4)
    print(Collector.task.redis)


# _*_ coding:utf-8 _*_
from copy import copy
from typing import Dict
from abc import abstractmethod, ABCMeta

from Xeu.configure.collection import Collection


class ConfigBase(metaclass=ABCMeta):

    @abstractmethod
    def get_current_env_data(self, *args, **kwargs):
        pass

    @property
    @abstractmethod
    def current_env_tag(self):
        pass


class Config(ConfigBase):

    def __init__(self, data: Dict, collection: Collection):
        self.data = data
        print(__class__,"collection", id(collection))
        self.__collection = collection
        print(__class__,"self.__collection", id(self.__collection))
        self.__collection.set("runtime", "env", self.data.get("runtime").get("env"))
        self.__collection.set("listen", "ipv4", self.data.get("listen").get(self.__collection.runtime.env)['ipv4'])
        self.__collection.set("listen", "port", self.data.get("listen").get(self.__collection.runtime.env)['port'])
        self.__collection.set("LISTEN", "ipv4", self.data.get("listen").get(self.__collection.runtime.env)['ipv4'])
        self.__collection.set("LISTEN", "port", self.data.get("listen").get(self.__collection.runtime.env)['port'])

        # Redis
        self.__collection.set("redis", "account", self.data.get("redis").get(self.__collection.runtime.env)['account'])
        self.__collection.set("redis", "password", self.data.get("redis").get(self.__collection.runtime.env)['password'])
        self.__collection.set("redis", "ipv4", self.data.get("redis").get(self.__collection.runtime.env)['ipv4'])
        self.__collection.set("redis", "port", self.data.get("redis").get(self.__collection.runtime.env)['port'])
        self.__collection.set("redis", "extends", self.data.get("redis").get(self.__collection.runtime.env)['extends'])

    def get_current_env_data(self, item: str):
        return self.__collection.runtime.env

    @property
    def current_env_tag(self):
        return self.__collection.runtime.env

    @property
    def current_env_data(self):
        return self.__collection


# -*- coding: utf-8 -*-
import os


__all__ = [
    'EXPIRE_TIME_SECONDS', 'BASE_DIR', 'SET_DEFAULT_HEADER', 'COOKIE_SECRET',
    'TEMPLATES_URL', 'STATIC_URL', 'STATIC_URL_PREFIX', 'INDEX_FILE'
]

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

COOKIE_SECRET = 'ulb7bEIZmwpV545Z'
EXPIRE_TIME_SECONDS = 60 * 30


STATIC_RELATIVE = 'static'
STATIC_URL = os.path.join(BASE_DIR, STATIC_RELATIVE)
STATIC_URL_PREFIX_RAW = 'Front'
STATIC_URL_PREFIX = '/' + STATIC_URL_PREFIX_RAW + '/'
INDEX_FILE = "admin.html"
TEMPLATES_RELATIVE = 'templates'
TEMPLATES_URL = os.path.join(BASE_DIR, TEMPLATES_RELATIVE)


SET_DEFAULT_HEADER = {
    "Access-Control-Allow-Credentials": "true",
    "Access-Control-Allow-Origin": "*",
    "Content-Type": "application/json",
    "Access-Control-Allow-Methods": "POST, GET, PUT, PATCH",
    "Access-Control-Allow-Headers": "Origin,Content-Type,Accept,token,X-Requested-With"
}

""" 上传文件包存放路径 """
UPLOAD_PACKAGE_URL = os.path.join(BASE_DIR, 'upload_package')
""" 上传 报告相关文件包 存放路径 """
UPLOAD_REPORT_PACKAGE_URL = os.path.join(BASE_DIR, 'upload_package', 'report')







import os
import logging
# import logging.handlers
import logging.config
from Xeu.configure.init import BASE_DIR
from Xeu.utils.DevConsole import StdoutColors

__all__ = ['Logger', ]

""" Log file storage path """
LOG_DIR = os.path.join(BASE_DIR, 'log')

# FileName = {
#     'defaut': os.path.join(LOG_DIR, 'request.log'),
#     'info': os.path.join(LOG_DIR, 'info.log'),
#     'debug': os.path.join(LOG_DIR, 'debug.log'),
#     'error': os.path.join(LOG_DIR, 'error.log')
# }
# Handler = {
#     'defaut': logging.handlers.RotatingFileHandler(FileName['defaut'], maxBytes = 1024*1024*50, backupCount = 5),
#     'info': logging.handlers.RotatingFileHandler(FileName['info'], maxBytes = 1024*1024*50, backupCount = 5),
#     'info-console': logging.StreamHandler(),
#     'debug': logging.handlers.RotatingFileHandler(FileName['debug'], maxBytes = 1024*1024*50, backupCount = 5),
#     'error': logging.handlers.RotatingFileHandler(FileName['error'], maxBytes = 1024*1024*50, backupCount = 5)
# }
# format = {
#     'simple': '[%(asctime)s] %(levelname)s : %(message)s',
#     'verbose': '[%(asctime)s] %(levelname)s %(module)s %(process)d %(thread)d : %(message)s',
#     'standard': '%(asctime)s [%(threadName)s:%(thread)d] [%(name)s:%(lineno)d] [%(levelname)s]-%(message)s',
#     'detail-info': '[%(asctime)s] [%(levelname)s] [%(threadName)s:%(thread)d] [%(module)s:%(lineno)d] %(message)s',
#     'color-detail-info': StdoutColors.WARNING +'[%(asctime)s] [%(levelname)s] [%(threadName)s:%(thread)d] [%(module)s:%(lineno)d] %(message)s',
#     'simple-info': '[%(asctime)s] [%(levelname)s] %(message)s',
#     'color-simple-info': StdoutColors.WARNING +'[%(asctime)s] [%(levelname)s] %(message)s',
#     'error': '[%(asctime)s] [%(levelname)s] [%(threadName)s:%(thread)d] [%(module)s:%(lineno)d] %(message)s',
#     'color-error': StdoutColors.FAIL + '[%(asctime)s] [%(levelname)s] [%(threadName)s:%(thread)d] [%(module)s:%(lineno)d] %(message)s',
#     'error-http': '[%(asctime)s] [%(threadName)s:%(thread)d] [%(name)s:%(lineno)d] [%(levelname)s] %(message)s',
#     'user-defined': '[%(asctime)s] [%(processName)s:%(process)d] [%(filename)s:%(lineno)d] [%(levelname)s]: %(message)s'
# }
#
# info_formatter = logging.Formatter(format['user-defined'])
# console_info_formatter = logging.Formatter(format['user-defined'])
# Handler['info'].setFormatter(info_formatter)
# Handler['info-console'].setFormatter(console_info_formatter)
# Logger = logging.getLogger(__file__)
# # Logger.addHandler(Handler['info'])
# Logger.addHandler(Handler['info-console'])
# # Logger.setLevel(logging.DEBUG)
# Logger.setLevel(logging.INFO)

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'simple': {'format': '[%(asctime)s] %(levelname)s : %(message)s'},
        'verbose': {'format': '[%(asctime)s] %(levelname)s %(module)s %(process)d %(thread)d : %(message)s'},
        'standard': {'format': '%(asctime)s [%(threadName)s:%(thread)d] [%(name)s:%(lineno)d] [%(levelname)s]-%(message)s'},
        'detail-info': {'format': '[%(asctime)s] [%(levelname)s] [%(threadName)s:%(thread)d] [%(module)s:%(lineno)d] %(message)s'},
        'color-detail-info': {
            'format': StdoutColors.WARNING +f'[%(asctime)s] [%(levelname)s] [%(threadName)s:%(thread)d] [%(module)s:%(lineno)d] %(message)s' + StdoutColors.ENDC
        },
        'simple-info': {'format': '[%(asctime)s] [%(levelname)s] %(message)s'},
        'color-simple-info': {'format': StdoutColors.WARNING +'[%(asctime)s] [%(levelname)s] %(message)s' + StdoutColors.ENDC},
        'error': {'format': '[%(asctime)s] [%(levelname)s] [%(threadName)s:%(thread)d] [%(module)s:%(lineno)d] %(message)s'},
        'color-error': {
            'format': StdoutColors.FAIL + '[%(asctime)s] [%(levelname)s] [%(threadName)s:%(thread)d] [%(module)s:%(lineno)d] %(message)s'},
        'error-http': {'format': '[%(asctime)s] [%(threadName)s:%(thread)d] [%(name)s:%(lineno)d] [%(levelname)s] %(message)s'},
    },
    'handlers': {
        'console-debug-default': {'level': 'DEBUG', 'formatter': 'standard', 'class': 'logging.StreamHandler'},
        'console-simple-info': {'level': 'INFO', 'formatter': 'color-simple-info', 'class': 'logging.StreamHandler'},
        'console-detail-info': {'level': 'INFO', 'formatter': 'color-detail-info', 'class': 'logging.StreamHandler'},
        'console_error': {'level': 'INFO', 'formatter': 'color-error', 'class': 'logging.StreamHandler'},
        'file-debug-default': {
            'level': 'DEBUG', 'formatter': 'standard', 'class': 'logging.handlers.RotatingFileHandler',
            'filename': os.path.join(LOG_DIR, 'debug.log'), 'maxBytes': 1024 * 1024 * 50, 'backupCount': 3,
        },
        'request_handler': {
            'level': 'DEBUG', 'formatter': 'standard', 'class': 'logging.handlers.RotatingFileHandler',
            'filename': os.path.join(LOG_DIR, 'request.log'), 'maxBytes': 1024 * 1024 * 50, 'backupCount': 3,
        },

        'file-error': {
            'level': 'ERROR', 'formatter': 'error', 'class': 'logging.handlers.RotatingFileHandler',
            'filename': os.path.join(LOG_DIR, 'error.log'), 'maxBytes': 1024 * 1024 * 50, 'backupCount': 3, 'mode': 'a',
        },
        'file-simple-info': {
            'level': 'INFO', 'formatter': 'simple-info', 'class': 'logging.handlers.RotatingFileHandler',
            'filename': os.path.join(LOG_DIR, 'info.log'), 'maxBytes': 1024 * 1024 * 50, 'backupCount': 3, 'mode': 'a',
        },
        'file-detail-info': {
            'level': 'INFO', 'formatter': 'detail-info', 'class': 'logging.handlers.RotatingFileHandler',
            'filename': os.path.join(LOG_DIR, 'info.log'), 'maxBytes': 1024 * 1024 * 50, 'backupCount': 10, 'mode': 'a',
        },
        # 'request': {
        #     'level': 'DEBUG',
        #     'class': 'logging.handlers.RotatingFileHandler',
        #     'filename': os.path.join(LOG_DIR, 'request.log'),
        #     'maxBytes': 1024 * 1024 * 50,
        #     'backupCount': 5,
        #     'formatter': 'simple',
        # },
        # 'console_error_file': {
        #     'level': 'ERROR',
        #     'class': 'logging.handlers.RotatingFileHandler',
        #     'filename': os.path.join(LOG_DIR, 'console.log'),
        #     'formatter': 'standard',
        # },
        # 'file-http': {
        #     'level': 'INFO',
        #     'class': 'logging.handlers.HTTPHandler',
        #     'formatter': 'standard',
        #     "host": "127.0.0.1:8080",
        #     "url": "/log_server",
        #     "method": "POST",
        # },
    },

    'loggers': {
        'simple-info': {'handlers': ['file-simple-info', 'console-simple-info'], 'level': 'INFO', 'propagate': False},
        'detail-info': {'handlers': ['file-detail-info', 'console-detail-info'], 'level': 'INFO', 'propagate': False},
        'critical': {'handlers': ['file-detail-info', 'console-detail-info'], 'level': 'INFO', 'propagate': False},
        'error': {'handlers': ['file-error', 'console_error'], 'level': 'ERROR', 'propagate': False},
        'debug': {'handlers': ['console-debug-default', 'file-debug-default'], 'level': 'DEBUG', 'propagate': False},
        # 'request': {
        #     'handlers': ['request'],
        #     'level': 'INFO',
        #     'propagate': True,
        # },
        # 'http_request': {
        #     'handlers': ['console_error'],
        #     'level': 'ERROR',
        #     'propagate': True,
        # },
        # 'django.request': {
        #     'handlers': ['request_handler'],
        #     'level': 'ERROR',
        #     'propagate': False,
        # },
    }

}

logging.config.dictConfig(LOGGING)


class Logger(object):
    @classmethod
    def info(cls, *args, **kwargs):
        pass

    @classmethod
    def error(cls, *args, **kwargs):
        pass

""" 应用自定义的数据库模板的方法 """
Logger.applyTemp = logging.getLogger

""" 应用缺省的数据库模板的方法 """
Logger.getLogger = logging.getLogger
Logger.info = logging.getLogger('detail-info').info
Logger.error = logging.getLogger('error').error
Logger.critical = logging.getLogger('critical').critical

